"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.startSideEffectsFrom = void 0;

var _lodash = _interopRequireDefault(require("lodash.partial"));

var _withAdapter = require("./with-adapter");

var _withEncryption = require("./with-encryption");

var _allowSideEffects = require("./allow-side-effects");

var _withSecretsManager = require("./with-secrets-manager");

var _makeAssertions = require("./make-assertions");

var startSideEffectsFrom = function startSideEffectsFrom(context, date) {
  var environment = context.environment;

  if (environment.isExecuted()) {
    throw Error("Side effects start time cannot be assigned if the test was executed.");
  }

  if (date instanceof Date) {
    environment.setSideEffectsStartTimestamp(date.getTime());
  } else if (typeof date === 'string') {
    environment.setSideEffectsStartTimestamp(Date.parse(date));
  } else {
    environment.setSideEffectsStartTimestamp(date);
  }

  return Object.assign((0, _makeAssertions.makeAssertions)(context), {
    withAdapter: (0, _lodash["default"])(_withAdapter.withAdapter, context),
    withEncryption: (0, _lodash["default"])(_withEncryption.withEncryption, context),
    allowSideEffects: (0, _lodash["default"])(_allowSideEffects.allowSideEffects, context),
    withSecretsManager: (0, _lodash["default"])(_withSecretsManager.withSecretsManager, context)
  });
};

exports.startSideEffectsFrom = startSideEffectsFrom;
//# sourceMappingURL=start-side-effects-from.js.map